==> libreoffice-libs-gui-3.3.1.2.tar.bz2: libreoffice-libs-gui-3.3.1.2/tools/inc/tools/prex.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * 
 * Copyright 2000, 2010 Oracle and/or its affiliates.
 *
 * OpenOffice.org - a multi-platform office productivity suite
 *
 * This file is part of OpenOffice.org.
 *
 * OpenOffice.org is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * OpenOffice.org is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details
 * (a copy is included in the LICENSE file that accompanied this code).
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with OpenOffice.org.  If not, see
 * <http://www.openoffice.org/license.html>
 * for a copy of the LGPLv3 License.
 *
 ************************************************************************/

#ifndef _PREX_H
#define _PREX_H

#define Window		XLIB_Window
#define BYTE		XLIB_BYTE
#define INT8		XLIB_INT8
#define INT64       XLIB_INT64
#define BOOL		XLIB_BOOL
#define Font		XLIB_Font
#define Cursor		XLIB_Cursor
#define String		XLIB_String
#define KeyCode		XLIB_KeyCode
#define Region		XLIB_Region
#define Icon		XLIB_Icon
#define Time		XLIB_Time
#define Region		XLIB_Region
#define Boolean		XLIB_Boolean

#if defined __cplusplus
extern "C" {
#endif

#if defined(LINUX) || defined(FREEBSD) || defined(MACOSX) || defined(NETBSD) || defined(OPENBSD) // should really check for xfree86 or for X11R6.1 and higher
#define __XKeyboardExtension__ 1
#else
#define __XKeyboardExtension__ 0
#endif

#include <X11/X.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/StringDefs.h>
#include <X11/extensions/Xrender.h>
#if __XKeyboardExtension__
#include <X11/XKBlib.h>
#endif
typedef unsigned long Pixel;

#undef  DestroyAll
#define DestroyAll		XLIB_DestroyAll
#define XLIB_DestroyAll	0
#undef  String
#define String			XLIB_String

#undef  KeyCode
#define KeyCode			XLIB_KeyCode //undef in intrinsics

#define __Ol_OlXlibExt_h__

#endif

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-libs-gui-3.4.5.2.tar.bz2: libreoffice-libs-gui-3.4.5.2/tools/inc/tools/prex.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * 
 * Copyright 2000, 2010 Oracle and/or its affiliates.
 *
 * OpenOffice.org - a multi-platform office productivity suite
 *
 * This file is part of OpenOffice.org.
 *
 * OpenOffice.org is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * OpenOffice.org is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details
 * (a copy is included in the LICENSE file that accompanied this code).
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with OpenOffice.org.  If not, see
 * <http://www.openoffice.org/license.html>
 * for a copy of the LGPLv3 License.
 *
 ************************************************************************/

#ifndef _PREX_H
#define _PREX_H

#define Window		XLIB_Window
#define Font		XLIB_Font
#define Cursor		XLIB_Cursor
#define String		XLIB_String
#define KeyCode		XLIB_KeyCode
#define Region		XLIB_Region
#define Icon		XLIB_Icon
#define Time		XLIB_Time
#define Region		XLIB_Region
#define Boolean		XLIB_Boolean

#if defined __cplusplus
extern "C" {
#endif

// FIXME: should really check for xfree86 or for X11R6.1 and higher
#if defined(LINUX) || defined(FREEBSD) || defined(MACOSX) || defined(NETBSD) || \
    defined(OPENBSD) || defined(DRAGONFLY)
#define __XKeyboardExtension__ 1
#else
#define __XKeyboardExtension__ 0
#endif

#include <X11/X.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/StringDefs.h>
#include <X11/extensions/Xrender.h>
#if __XKeyboardExtension__
#include <X11/XKBlib.h>
#endif
typedef unsigned long Pixel;

#undef  DestroyAll
#define DestroyAll		XLIB_DestroyAll
#define XLIB_DestroyAll	0
#undef  String
#define String			XLIB_String

#undef  KeyCode
#define KeyCode			XLIB_KeyCode //undef in intrinsics

#define __Ol_OlXlibExt_h__

#endif

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
